Tadpole
-------

flask starter, provide simple flask app start and management,
integration with some useful flask extensions and frequently
used python packages,support restful view, auto restful
sqlalchemy model, auth and permission.


Installation
------------

Tadpole requires **Python 2.x >= 2.6**.

Install from PyPI::

    $ pip install tadpole


Usage
-----

Basic usage::

    $ tadpole init -n PROJECT_NAME -v PROJECT_VERSION -o PROJECT_OWNER -e PROJECT_EMAIL

Where ``PROJECT_NAME`` is your own project name and ``PROJECT_VERSION`` is your project init version,
``PROJECT_OWNER`` is the project owner name and ``PROJECT_EMAIL`` is email address of this project
（the logging email maybe sendto this address).

License
-------

tadpole is released under the MIT License. See the LICENSE_ file for more
details.

.. _LICENSE: https://github.com/echoyuanliang/tadpole/blob/master/LICENSE
